import { MessageBoxComponent } from './messagebox.component';
export declare abstract class BaseComponent {
    messageBox: MessageBoxComponent;
    calLang: any;
    /**
     * 解析国际化消息
     * @param key 键
     * @param params 参数
     */
    resolveMessage(key: string, ...params: string[]): string;
    /**
     * 生成下载链接。
     * @param uri 附件的相对路径
     */
    resolveDownloadUrl(uri: string): string;
    /**
     * 格式化日期
     * @param date 日期
     * @param pattern 格式，如 'yyyy-MM-dd hh:mm:ss.S', 'yyyy年qq季度'
     *
     */
    formatDate(date: Date, pattern: string): string;
    /**
     * 处理错误
     * @param error 错误对象
     */
    protected handleError(error: any, mBox?: MessageBoxComponent): void;
    /**
     * 显示错误消息
     * @param message 消息
     */
    protected showError(message: string): void;
    /**
     * i18n的显示警告消息
     * @param messageKey 要显示的消息key
     */
    protected showWarnKey(messageKey: string): void;
    /**
     * i18n的显示成功消息
     * @param messageKey 要显示的消息key
     */
    protected showSuccessKey(messageKey: string): void;
    /**
     * 	i18n的显示通知消息
     * @param messageKey 要显示的消息key
     */
    protected showInfoKey(messageKey: string): void;
    /**
     * 	i18n的显示错误消息
     * @param messageKey 要显示的消息key
     */
    protected showErrorKey(messageKey: string): void;
    /**
     * 显示消息
     * @param message 要显示的消息
     * @param style 消息风格，"warn","success","info","error"
     */
    protected showMessage(message: string, style: string): void;
    /**
     * 获取请求串中的参数值
     * @param name 参数名称
     *
     */
    protected getRequestParamValue(name: string): string;
    /**
     * 获取请求串中的参数值数组，如a=x&a=y, 则参数a的值为['x','y']
     * @param name 参数名称
     */
    protected getRequestParamValues(name: string): string[];
    /**
     * 判断是否有异步任务正在执行，以便界面显示相关信息，让用户等待
     */
    isRunning(): boolean;
}
