import { NodeBase, EdgeBase } from './models';
export declare class GraphUtils {
    /**
     * 把节点集和边集转换成图矩阵
     * @param nodes 节点集
     * @param edges 边集
     * @param directed 是否有向，缺省是无向图
     * @param distanceProp 边上的距离属性名
     */
    static toGraphMatrix(nodes: NodeBase<any>[], edges: EdgeBase<any>[], directed?: boolean, distanceProp?: string): number[][];
    private static getMatrix(length);
    /** 从某一源点出发，找到到所有结点的最短路径
     *
     * @param nodes 节点集合
     * @param edges 边集合
     * @param start 起点
     * @param directed 是否有向图，缺省为无向
     */
    static getShortedPathAll(nodes: NodeBase<any>[], edges: EdgeBase<any>[], start: NodeBase<any>, directed?: boolean): NodeBase<any>[][];
    /** 从某一源点出发，找到到某一结点的最短路径
     *
     * @param nodes 节点集合
     * @param edges 边集合
     * @param start 起点
     * @param end 终点
     * @param directed 是否有向图，缺省为无向
     */
    static getShortedPath(nodes: NodeBase<any>[], edges: EdgeBase<any>[], start: NodeBase<any>, end: NodeBase<any>, directed?: boolean): NodeBase<any>[];
    /**
     * 找到与指定节点相连的节点
     * @param nodes 节点集
     * @param edges 边集
     * @param start 指定节点
     * @param directed 是否有向图，缺省是无向图
     */
    static getConnectedNodes(nodes: NodeBase<any>[], edges: EdgeBase<any>[], start: NodeBase<any>, directed?: boolean): NodeBase<any>[];
    /**
     * 找到指定节点在节点集合中的位置
     * @param nodes 节点集合
     * @param v0 指定节点
     * @Returns 位置，0-based. 如果没找到就返回 undefined;
     */
    static getNodePosition(nodes: NodeBase<any>[], v0: NodeBase<any>): number;
    static isConnected(nodes: NodeBase<any>[], edges: EdgeBase<any>[], start: NodeBase<any>, end: NodeBase<any>, directed: boolean): boolean;
    static getConectedbyBfs(graph: number[][], start: number): number[];
    static isConectedbyBfs(arr: number[][], start: number, end: number): boolean;
}
