export declare class PagedQueryResult<T> {
    /**
     *满足条件的总数据条数
    */
    recordCount: number;
    /**
     * 满足条件的总页数
    */
    pageCount: number;
    /**
     * 当前页数据
    */
    datas: T[];
}
export declare abstract class PagedQueryParam {
    /**
     * 要查询第几页，从1开始
    */
    pageNumber: number;
    /**
     * 每页数据条数，缺省20
     * */
    pageSize: number;
    /**
    *排序，分号分隔每一组条件，组内用冒号分隔。
    *属性引用，如: seq:ASC; userCode:DESC 表示 seq升序，然后userCode降序
    *支持SQL条件，如：SQL:abs(VALUE_DIFF):ASC; SQL:decode(checked_summary,0,1,abs(VALUE_DIFF/checked_summary)):DESC
    */
    orderBy: string;
    changePage(event: DataEvent): void;
}
/**
 * primeng Table Paginator的事件数据结构
 */
export declare class DataEvent {
    /**
     * Index of the first record
     */
    first: number;
    /**
     * Number of rows to display in new page
     */
    rows: number;
    /**
     * Index of the new page
     */
    page: number;
    /**
     * Total number of pages
     */
    pageCount: number;
    /**
     * Field name to sort in single sort mode
     */
    sortField: string;
    /**
     * Sort order as number, 1 for asc and -1 for dec in single sort mode
     */
    sortOrder: number;
    /**
     * An array of SortMeta objects used in multiple columns sorting. Each SortMeta has field and order properties.
     */
    multiSortMeta: SortMeta[];
}
export declare class SortMeta {
    /**
     * Field name to sort in single sort mode
     */
    sortField: string;
    /**
     * Sort order as number, 1 for asc and -1 for dec in single sort mode
     */
    sortOrder: number;
}
export declare class Selectable {
    isSelected: boolean;
}
export declare class RefBean extends Selectable {
    code: string;
    name: string;
    constructor(code: string, name: string);
}
export declare class RefBeanTreeNode extends RefBean {
    children: RefBeanTreeNode[];
}
export declare class RestResult {
    status: string;
    value: any;
}
/**
 * 图相关数据模型，节点基类。
 */
export declare class NodeBase<N> {
    /**
     * 节点的ID
     */
    id: string;
    /**
     * 节点的业务数据，如Customer
     */
    data: N;
}
/**
 * 图相关数据模型，连接节点的边基类
 */
export declare class EdgeBase<E> {
    /**
     * 源节点的ID
     */
    source: string;
    /**
     * 目标节点的ID
     */
    target: string;
    /**
     * 源节点到目标节点的距离，用于计算最短路径
     */
    distance: number;
    /**
     * 边相关的业务数据，如CustomerRelation
     */
    data: E;
}
