import { Selectable } from './models';
export declare class Utils {
    static resolveJsonErrorMessage(err: any): string;
    static showMessage(msg: string): void;
    static showMessageByKey(key: string): void;
    static cloneObject(src: Object, dist: Object): void;
    /** To use this function, the langMap variable should be defined already. e.g.
     * var langMap = {
     *     	"rolesDetail": '角色列表',
     *     	"msg.deletedSuccess": "删除成功!",
     *     	"msg.savedSuccess": "保存成功!",
     *     	"msg.addedSuccess": "新增成功!"
     *     }
     * @param key the message key
     * @param params parameters to replace the placeholder in message. If params is not an array, then treat it as the first parameter.
     * @returns resolved localized message. return the key if message not found.
     */
    static resolveLocalizedMessage(key: string, params?: string[]): any;
    /** Compare whether 2 arrays are same.
     * @param array1
     * @param array2
     * @param property
     * @returns true if same.
     */
    static compareArrays(array1: Array<any>, array2: Array<any>, property: string): boolean;
    /**
     * 取得当前数据日期
    */
    static getCurrentDataDate(): string;
    /**
     * 取得当前的出帐机构号
    */
    static getCurrentNodeCode(): string;
    /**
     * 取得指定的cookie变量值
    */
    static getCookie(name: string): any;
    /**
     * 设置指定的cookie变量值以及有效时间（毫秒）
    */
    static setCookie(name: string, value: string, msec?: number): void;
    /**
     * 删除指定的cookie变量
    */
    static delCookie(name: string): void;
    /**
     * 获取可选取列表中选中的项目
     * @param array 可选项目列表
     * @param property 返回的选中项目属性，如列表是TreeNode类型，而要返回的选中项可能是TreeNode.data,那么porperty就应该是“data”，如果不提供porperty，将返回列表中选中的TreeNode。
    */
    static getSelectedBeans(array: Selectable[], property?: string): any[];
    /**
     * 格式化数字显示方式
     * 用法
     * formatNumber(12345.999,'#,##0.00');
     * formatNumber(12345.999,'#,##0.##');
     * formatNumber(123,'000000');
     * @param num  要格式化的数字
     * @param pattern  想要的格式
     */
    static formatNumber(num: number, pattern: string): string;
    /**
     * 将日期串转换成日期类型的变量
     * @param dateStr 日期串，支持如2018-10-31, 20181031, 31/10/2018等格式
     *
     */
    static parseDate(dateStr: string): Date;
    /**
     * 将日期按照指定的格式格式化成字符串用于显示
     * @param date 日期
     * @param fmt 想要的格式，如：“yyyy-MM-dd hh:mm:ss S”, “yyyy年第q季度”
     */
    static formatDate(date: Date, fmt: string): string;
    /**
     * 获取请求参数
     * @param name 参数名
     */
    static getParameter(name: string): string;
}
