"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Utils = /** @class */ (function () {
    function Utils() {
    }
    Utils.resolveJsonErrorMessage = function (err) {
        var rn = "\r\n";
        var msg = Utils.resolveLocalizedMessage("msg.errorOccurred");
        if (err._body) {
            err = err.json();
            if (err.defaultMessage) {
                if (err.code) {
                    msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorCode") + "：" + err.code;
                }
                if (err.localizedMessage) {
                    msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorMessage") + "：" + err.localizedMessage;
                }
                else {
                    msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorMessage") + "：" + err.defaultMessage;
                }
                if (err.cause) {
                    msg = msg + rn + Utils.resolveLocalizedMessage("msg.rootMessage") + "：" + err.cause;
                }
                //Utils.showMessage(msg);
                return msg;
            }
        }
        if (err.message) {
            msg = msg + rn + Utils.resolveLocalizedMessage("msg.rootMessage") + "：" + err.message;
        }
        if (err.status) {
            msg = msg + rn + Utils.resolveLocalizedMessage("msg.httpStatus") + err.status;
            msg = msg + rn + Utils.resolveLocalizedMessage("msg.returnMessage") + err.statusText;
        }
        return msg;
    };
    Utils.showMessage = function (msg) {
        alert(msg);
    };
    Utils.showMessageByKey = function (key) {
        Utils.showMessage(Utils.resolveLocalizedMessage(key));
    };
    Utils.cloneObject = function (src, dist) {
        for (var prop in src) {
            dist[prop] = src[prop];
        }
    };
    /** To use this function, the langMap variable should be defined already. e.g.
     * var langMap = {
     *     	"rolesDetail": '角色列表',
     *     	"msg.deletedSuccess": "删除成功!",
     *     	"msg.savedSuccess": "保存成功!",
     *     	"msg.addedSuccess": "新增成功!"
     *     }
     * @param key the message key
     * @param params parameters to replace the placeholder in message. If params is not an array, then treat it as the first parameter.
     * @returns resolved localized message. return the key if message not found.
     */
    Utils.resolveLocalizedMessage = function (key, params) {
        var msg = langMap[key];
        if (msg == undefined) {
            return key;
        }
        if (params) {
            if (params.length) {
                for (var i = 0; i < params.length; i++) {
                    msg = msg.replace("{" + i + "}", params[i]);
                }
            }
            else {
                msg = msg.replace("{0}", params);
            }
        }
        return msg;
    };
    /** Compare whether 2 arrays are same.
     * @param array1
     * @param array2
     * @param property
     * @returns true if same.
     */
    Utils.compareArrays = function (array1, array2, property) {
        if (array1.length != array2.length) {
            return false;
        }
        for (var i = 0; i < array1.length; i++) {
            var obj1 = array1[i];
            var found = false;
            for (var k = 0; k < array2.length; k++) {
                var obj2 = array2[k];
                if (property) {
                    if (obj2[property] == obj1[property]) {
                        found = true;
                        break;
                    }
                }
                else {
                    if (obj2 == obj1) {
                        found = true;
                        break;
                    }
                }
            }
            if (!found) {
                return false;
            }
        }
        return true;
    };
    /**
     * 取得当前数据日期
    */
    Utils.getCurrentDataDate = function () {
        return Utils.getCookie("currentDataDate");
    };
    /**
     * 取得当前的出帐机构号
    */
    Utils.getCurrentNodeCode = function () {
        return Utils.getCookie("currentNodeCode");
    };
    /**
     * 取得指定的cookie变量值
    */
    Utils.getCookie = function (name) {
        var arr, reg = new RegExp("(^| )" + name + "=([^;]*)(;|$)"); //正则匹配
        if (arr = document.cookie.match(reg)) {
            return unescape(arr[2]);
        }
        else {
            return null;
        }
    };
    /**
     * 设置指定的cookie变量值以及有效时间（毫秒）
    */
    Utils.setCookie = function (name, value, msec) {
        var cs = name + '=' + escape(value);
        if (msec) {
            var exp = new Date();
            exp.setTime(exp.getTime() + msec * 1);
            cs += ";expires=" + exp.toUTCString();
        }
        document.cookie = cs;
    };
    /**
     * 删除指定的cookie变量
    */
    Utils.delCookie = function (name) {
        var exp = new Date();
        exp.setTime(exp.getTime() - 1);
        var cval = Utils.getCookie(name);
        if (cval != null) {
            document.cookie = name + "=" + cval + ";expires=" + exp.toUTCString();
        }
    };
    /**
     * 获取可选取列表中选中的项目
     * @param array 可选项目列表
     * @param property 返回的选中项目属性，如列表是TreeNode类型，而要返回的选中项可能是TreeNode.data,那么porperty就应该是“data”，如果不提供porperty，将返回列表中选中的TreeNode。
    */
    Utils.getSelectedBeans = function (array, property) {
        var rst = new Array();
        for (var _i = 0, array_1 = array; _i < array_1.length; _i++) {
            var s = array_1[_i];
            if (s.isSelected) {
                if (property) {
                    rst.push(s[property]);
                }
                else {
                    rst.push(s);
                }
            }
        }
        return rst;
    };
    /**
     * 格式化数字显示方式
     * 用法
     * formatNumber(12345.999,'#,##0.00');
     * formatNumber(12345.999,'#,##0.##');
     * formatNumber(123,'000000');
     * @param num  要格式化的数字
     * @param pattern  想要的格式
     */
    Utils.formatNumber = function (num, pattern) {
        var strarr = num ? num.toString().split('.') : ['0'];
        var fmtarr = pattern ? pattern.split('.') : [''];
        var retstr = '';
        // 整数部分   
        var str = strarr[0];
        var fmt = fmtarr[0];
        var i = str.length - 1;
        var comma = false;
        for (var f = fmt.length - 1; f >= 0; f--) {
            switch (fmt.substr(f, 1)) {
                case '#':
                    if (i >= 0)
                        retstr = str.substr(i--, 1) + retstr;
                    break;
                case '0':
                    if (i >= 0)
                        retstr = str.substr(i--, 1) + retstr;
                    else
                        retstr = '0' + retstr;
                    break;
                case ',':
                    comma = true;
                    retstr = ',' + retstr;
                    break;
            }
        }
        if (i >= 0) {
            if (comma) {
                var l = str.length;
                for (; i >= 0; i--) {
                    retstr = str.substr(i, 1) + retstr;
                    if (i > 0 && ((l - i) % 3) == 0)
                        retstr = ',' + retstr;
                }
            }
            else
                retstr = str.substr(0, i + 1) + retstr;
        }
        retstr = retstr + '.';
        // 处理小数部分   
        str = strarr.length > 1 ? strarr[1] : '';
        fmt = fmtarr.length > 1 ? fmtarr[1] : '';
        i = 0;
        for (var f = 0; f < fmt.length; f++) {
            switch (fmt.substr(f, 1)) {
                case '#':
                    if (i < str.length)
                        retstr += str.substr(i++, 1);
                    break;
                case '0':
                    if (i < str.length)
                        retstr += str.substr(i++, 1);
                    else
                        retstr += '0';
                    break;
            }
        }
        return retstr.replace(/^,+/, '').replace(/\.$/, '');
    };
    /**
     * 将日期串转换成日期类型的变量
     * @param dateStr 日期串，支持如2018-10-31, 20181031, 31/10/2018等格式
     *
     */
    Utils.parseDate = function (dateStr) {
        if (dateStr.length == 8) {
            //yyyyMMdd格式
            var year = parseInt(dateStr.substr(0, 4));
            var month = parseInt(dateStr.substr(4, 2));
            var day = parseInt(dateStr.substr(6, 2));
            return new Date(year, month - 1, day);
        }
        //其它格式
        return new Date(dateStr);
    };
    /**
     * 将日期按照指定的格式格式化成字符串用于显示
     * @param date 日期
     * @param fmt 想要的格式，如：“yyyy-MM-dd hh:mm:ss S”, “yyyy年第q季度”
     */
    Utils.formatDate = function (date, fmt) {
        var o = {
            "M+": date.getMonth() + 1,
            "d+": date.getDate(),
            "h+": date.getHours(),
            "m+": date.getMinutes(),
            "s+": date.getSeconds(),
            "q+": Math.floor((date.getMonth() + 3) / 3),
            "S": date.getMilliseconds() //毫秒   
        };
        if (/(y+)/.test(fmt))
            fmt = fmt.replace(RegExp.$1, (date.getFullYear() + "").substr(4 - RegExp.$1.length));
        for (var k in o)
            if (new RegExp("(" + k + ")").test(fmt))
                fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
        return fmt;
    };
    /**
     * 获取请求参数
     * @param name 参数名
     */
    Utils.getParameter = function (name) {
        var reqUrl = document.location.href;
        var re = new RegExp(name + '=([^&]*)(?:&)?');
        var val = reqUrl.match(re) && reqUrl.match(re)[1];
        if (val) {
            val = decodeURI(val);
        }
        return val;
    };
    ;
    return Utils;
}());
exports.Utils = Utils;
//# sourceMappingURL=utils.js.map